🔸ESAR — PolSARtools 0.9 documentation

Skip to main content
`Ctrl`+`K`

# 🔸ESAR

## GTC SLC (`esar_gtc`)

The esar_gtc function extracts Sxy/C2/T2 (for dual-pol), S2/C4/T4/C3/T3/C2/T2 (for full-pol) matrix elements from a ESAR GTC SLC data folder and saves them into a directory.

polsartools.esar_gtc(in_dir, mat='S2', azlks=3, rglks=3, fmt='tif', cog=False, ovr=[2, 4, 8, 16], comp=False, out_dir=None, recip=False)

  Extracts the Sxy/C2/T2 (for dual-pol), S2/C4/T4/C3/T3/C2/T2 (for full-pol) matrix elements from a ESAR GTC SLC data

  ### Example:

      >>> esar_gtc("path_to_folder", mat='C3', azlks=3, rglks=3)
      This will extract the C3 from full-pol ESAR GTC SLC data and save them as geotiff files.
      Additionally, it will also extract the incidence angle map and save it as a geotiff file.

  ### Parameters:

  in_dirstr

    The path to the ESAR GTC folder containing the data and metadata.

  matstr, optional (default = ‘S2’ or ‘Sxy)

    Type of matrix to extract. Valid options for Full-pol: ‘S2’, ‘C4, ‘C3’, ‘T4’, ‘T3’, ‘C2HX’, ‘C2VX’, ‘C2HV’,’T2HV’and Dual-pol: ‘Sxy’,’C2’, ‘T2’.

  azlksint, optional (default=3)

    The number of azimuth looks for multi-looking.

  rglksint, optional (default=3)

    The number of range looks for multi-looking.

  fmt{‘tif’, ‘bin’}, optional (default=’tif’)

    Output format: - ‘tif’: GeoTIFF with georeferencing - ‘bin’: Raw binary format

  cogbool, optional (default=False)

    If True, outputs will be saved as Cloud Optimized GeoTIFFs with internal tiling and overviews.

  ovrlist of int, optional (default=[2, 4, 8, 16])

    Overview levels for COG generation. Ignored if cog=False.

  compbool, optional (default=False)

    If True, applies LZW compression to GeoTIFF outputs.

  out_dirstr or None, optional (default=None)

    Directory to save output files. If None, a folder named after the matrix type will be created in the same location as the input file.

  recipbool, optional (default=False)

    If True, scattering matrix reciprocal symmetry is applied, i.e, S_HV = S_VH.

  ### Returns:

  None

    The function does not return any value. Instead, it creates a folder named S2/C3/T3/C2/T2 (if not already present) and saves the geotiff/binary files: